/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA;
typedef struct tySequence__9akYQg9bGGWN2vXNeTTLyhlQ tySequence__9akYQg9bGGWN2vXNeTTLyhlQ;
typedef struct tySequence__IZ4pqIhlSxW1ShEsUUFl9bg tySequence__IZ4pqIhlSxW1ShEsUUFl9bg;
typedef struct tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA;
typedef struct tyTuple__4xveOqHv9bUHQvrUN5zZghg tyTuple__4xveOqHv9bUHQvrUN5zZghg;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct RootObj RootObj;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct NimStringDesc NimStringDesc;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
struct tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg {
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* s;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g;
NIM_BOOL beSmart;
};
struct tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA {
tySequence__9akYQg9bGGWN2vXNeTTLyhlQ* locals;
tySequence__IZ4pqIhlSxW1ShEsUUFl9bg* slices;
tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg guards;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* args;
NI spawns;
NI currentSpawnId;
NI inLoop;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
};
struct TGenericSeq {
NI len;
NI reserved;
};
typedef NU8 tyEnum_TDirection__Q9bgfkfWy7Of6Rrlhl66fXA;
struct tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* alias;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lower;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* upper;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* stride;
tyEnum_TDirection__Q9bgfkfWy7Of6Rrlhl66fXA dir;
NIM_BOOL blacklisted;
};
struct tyTuple__4xveOqHv9bUHQvrUN5zZghg {
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field0;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
NI Field3;
NIM_BOOL Field4;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg;
typedef NU16 tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NimStringDesc* tyArray__yt5VDPNtUGx9cBkOVakHwdQ[6];
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef NU8 tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA;
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__9akYQg9bGGWN2vXNeTTLyhlQ {
  TGenericSeq Sup;
  tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA data[SEQ_DECL_SIZE];
};
struct tySequence__IZ4pqIhlSxW1ShEsUUFl9bg {
  TGenericSeq Sup;
  tyTuple__4xveOqHv9bUHQvrUN5zZghg data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initAnalysisCtx__semparallel_44)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* Result);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, analyse__semparallel_442)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipConv__types_3655)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSingleAssignable__semparallel_200)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLocal__semparallel_220)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA*, getSlot__semparallel_120)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v);
N_LIB_PRIVATE N_NIMCALL(NI, lookupSlot__semparallel_99)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__9akYQg9bGGWN2vXNeTTLyhlQ)(void* p, NI op);
static N_INLINE(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA*, X5BX5D___semparallel_132)(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(void, invalidateFacts__guards_760)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag, getMagic__trees_137)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op);
N_LIB_PRIVATE N_NIMCALL(void, gatherArgs__semparallel_172)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getRoot__trees_390)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5310)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5272)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5317)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5315)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5266)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(void, analyseSons__semparallel_445)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, addAsgnFact__guards_1739)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value);
N_LIB_PRIVATE N_NIMCALL(void, analyseCall__semparallel_464)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(NIM_BOOL, fromSystem__astalgo_238)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getModule__astalgo_216)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, min__semparallel_454)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipStmtList__ast_4813)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, addSlice__semparallel_294)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri);
N_LIB_PRIVATE N_NIMCALL(void, checkLocal__semparallel_240)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, canon__guards_345)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg* o);
N_LIB_PRIVATE N_NIMCALL(void, addLowerBoundAsFacts__semparallel_264)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c);
N_LIB_PRIVATE N_NIMCALL(void, addFactLe__guards_1643)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3704)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, checkBounds__semparallel_260)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arr, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* idx);
N_LIB_PRIVATE N_NIMCALL(void, checkLe__semparallel_256)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg, proveLe__guards_1628)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__renderer_46)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lowBound__guards_261)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, highBound__guards_265)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg* o);
static N_NIMCALL(void, Marker_tySequence__IZ4pqIhlSxW1ShEsUUFl9bg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(void, analyseCase__semparallel_501)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, addCaseBranchFacts__guards_1764)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI i);
N_LIB_PRIVATE N_NIMCALL(void, analyseIf__semparallel_536)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, addFact__guards_609)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nn);
N_LIB_PRIVATE N_NIMCALL(void, addFactNeg__guards_632)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrue__trees_375)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSubnodeWith__ast_4571)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind);
N_LIB_PRIVATE N_NIMCALL(void, checkSlicesAreDisjoint__semparallel_368)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c);
N_LIB_PRIVATE N_NIMCALL(void, overlap__semparallel_323)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* d);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, subStride__semparallel_349)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, buildAdd__guards_494)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, NI64 b, tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg* o);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, shallowCopy__ast_4414)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTree__guards_680)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(NI64, simpleSlice__guards_1048)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(NI64, stride__semparallel_330)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, checkArgs__semparallel_849)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, newSym__ast_3409)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symKind, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getIdent__idents_152)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* ic, NimStringDesc* identifier);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getCompilerProc__magicsys_145)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(void, addVar__lowerings_63)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, genAddrOf__lowerings_626)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg typeKind);
N_LIB_PRIVATE N_NIMCALL(void, generateAliasChecks__semparallel_852)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, callCodegenProc__lowerings_641)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NimStringDesc* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg1, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg2, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg3, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* optionalArgs);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, transformSpawn__semparallel_753)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* barrier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, transformSlices__semparallel_699)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyNode__ast_4324)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newType__ast_3884)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(void, add__concepts_23)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, createMagic__modulegraphs_9046)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, NimStringDesc* name, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getSysType__magicsys_60)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA, spawnResult__spawn_34)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NIM_BOOL inParallel);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, wrapProcForSpawn__spawn_510)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* spawnExpr, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* retType, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* barrier, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dest);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, transformSpawnSons__semparallel_759)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* barrier);
N_LIB_PRIVATE TNimType NTImonotonicvar__nLLlLWL1ObfBpnV7hTHjSA_;
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
N_LIB_PRIVATE TNimType NTItdirection__Q9bgfkfWy7Of6Rrlhl66fXA_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTIseqLmonotonicvarT__9akYQg9bGGWN2vXNeTTLyhlQ_;
extern TNimType NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_6, "+=", 2);
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_7, "[]", 2);
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_8, "invalid usage of counter after increment", 40);
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_10, "/home/runner/work/nightlies/nightlies/nim/compiler/semparallel.nim", 66);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_9 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 123),
((NI) 16)}
;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_11, "cannot prove: ", 14);
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_12, " <= ", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_13 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 132),
((NI) 11)}
;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_14, "can prove: ", 11);
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_15, " > ", 3);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_16 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 136),
((NI) 11)}
;
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
N_LIB_PRIVATE TNimType NTItupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolT__4xveOqHv9bUHQvrUN5zZghg_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTIseqLtupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolTT__IZ4pqIhlSxW1ShEsUUFl9bg_;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_18, "[]=", 3);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__JbTimwuMPgU1h9bmgifZk6Q_19 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_20, "invalid control flow for \'parallel\'", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_21 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 355),
((NI) 14)}
;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_22, "slot already has a lower bound", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_23 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 371),
((NI) 31)}
;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_24, "\'parallel\' section without \'spawn\'", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_25 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 484),
((NI) 14)}
;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_26, "cannot prove: $# > $#; required for ($#)..($#) disjoint from ($#)..($#)", 71);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_27 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 167),
((NI) 13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_28 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 173),
((NI) 13)}
;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_29, "($#)..($#) not disjoint from ($#)..($#)", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_30 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 177),
((NI) 13)}
;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_31, "cannot prove ($#)..($#) disjoint from ($#)..($#)", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_32 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 250),
((NI) 22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_33 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 253),
((NI) 20)}
;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_34, "barrier", 7);
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_35, "Barrier", 7);
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_36, "openBarrier", 11);
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_37, "invalid context for \'spawn\'", 27);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JbTimwuMPgU1h9bmgifZk6Q_38 = {((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_10),
((NI) 436),
((NI) 34)}
;
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_39, "slice", 5);
STRING_LITERAL(TM__JbTimwuMPgU1h9bmgifZk6Q_40, "closeBarrier", 12);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5219;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(void, initAnalysisCtx__semparallel_44)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* Result) {
	unsureAsgnRef((void**)&(*Result).locals, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).slices, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.s, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.g, NIM_NIL);
	(*Result).guards.beSmart = 0;
	unsureAsgnRef((void**)&(*Result).args, NIM_NIL);
	(*Result).spawns = 0;
	(*Result).currentSpawnId = 0;
	(*Result).inLoop = 0;
	unsureAsgnRef((void**)&(*Result).graph, NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).locals), NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).slices), NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).args), NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).guards.s), NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).guards.g), g);
	unsureAsgnRef((void**) (&(*Result).graph), g);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSingleAssignable__semparallel_200)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T1_)) goto LA2_;
	s = (*n)._kind_4.sym;
	T3_ = (NIM_BOOL)0;
	T3_ = ((2097696 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T3_)) goto LA4_;
	T3_ = ((131080 & (*s).flags) == 0);
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLocal__semparallel_220)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T1_)) goto LA2_;
	s = (*n)._kind_4.sym;
	T3_ = (NIM_BOOL)0;
	T3_ = ((2100000 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T3_)) goto LA4_;
	T3_ = ((131080 & (*s).flags) == 0);
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, lookupSlot__semparallel_99)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NI result;
{	result = (NI)0;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*c).locals ? (*c).locals->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*c).locals->data[i].v == s);
					if (T7_) goto LA8_;
					T7_ = ((*c).locals->data[i].alias == s);
					LA8_: ;
					if (!T7_) goto LA9_;
					result = i;
					goto BeforeRet_;
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	result = ((NI) -1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__9akYQg9bGGWN2vXNeTTLyhlQ)(void* p, NI op) {
	tySequence__9akYQg9bGGWN2vXNeTTLyhlQ* a;
	NI T1_;
	a = (tySequence__9akYQg9bGGWN2vXNeTTLyhlQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].v, op);
	nimGCvisit((void*)a->data[T1_].alias, op);
	nimGCvisit((void*)a->data[T1_].lower, op);
	nimGCvisit((void*)a->data[T1_].upper, op);
	nimGCvisit((void*)a->data[T1_].stride, op);
	}
}
static N_INLINE(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA*, X5BX5D___semparallel_132)(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA* s, NI sLen_0, NI i) {
	tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA* result;
	result = (tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA*, getSlot__semparallel_120)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v) {
	tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA* result;
	NI s;
	NI T5_;
	tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA* T6_;
{	result = (tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA*)0;
	s = lookupSlot__semparallel_99((&(*c)), v);
	{
		if (!(((NI) 0) <= s)) goto LA3_;
		result = (&(*c).locals->data[s]);
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = ((*c).locals ? (*c).locals->Sup.len : 0);
	unsureAsgnRef((void**) (&(*c).locals), (tySequence__9akYQg9bGGWN2vXNeTTLyhlQ*) setLengthSeqV2(((*c).locals)?&((*c).locals)->Sup:NIM_NIL, (&NTIseqLmonotonicvarT__9akYQg9bGGWN2vXNeTTLyhlQ_), ((NI) ((NI)(T5_ + ((NI) 1))))));
	T6_ = (tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA*)0;
	T6_ = X5BX5D___semparallel_132(((*c).locals) ? ((*c).locals->data) : NIM_NIL, ((*c).locals ? (*c).locals->Sup.len : 0), ((NI) 1));
	unsureAsgnRef((void**) (&(*T6_).v), v);
	result = X5BX5D___semparallel_132(((*c).locals) ? ((*c).locals->data) : NIM_NIL, ((*c).locals ? (*c).locals->Sup.len : 0), ((NI) 1));
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5310)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5272)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5315)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5266((&gch__system_5219.zct), c);
}
static N_INLINE(void, decRef__system_5317)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5315(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5272(src);
		incRef__system_5310(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5272((*dest));
		decRef__system_5317(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, gatherArgs__semparallel_172)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__ast_3148(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* root;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				root = getRoot__trees_390((*n)._kind_6.sons->data[i]);
				{
					if (!!((root == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA6_;
					{
						NI T17_;
						{
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** r;
							NI i_3;
							NI L;
							NI T10_;
							r = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
							i_3 = ((NI) 0);
							T10_ = ((*c).args ? (*c).args->Sup.len : 0);
							L = T10_;
							{
								while (1) {
									if (!(i_3 < L)) goto LA12;
									r = &(*c).args->data[i_3];
									{
										if (!((*r) == root)) goto LA15_;
										goto LA8;
									}
									LA15_: ;
									i_3 += ((NI) 1);
								} LA12: ;
							}
						}
						unsureAsgnRef((void**) (&(*c).args), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) incrSeqV3((TGenericSeq*)((*c).args), (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_)));
						T17_ = (*c).args->Sup.len++;
						asgnRef((void**) (&(*c).args->data[T17_]), root);
					} LA8: ;
				}
				LA6_: ;
				gatherArgs__semparallel_172(c, (*n)._kind_6.sons->data[i]);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, analyseSons__semparallel_445)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__ast_3148(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				analyse__semparallel_442(c, (*n)._kind_6.sons->data[i]);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, fromSystem__astalgo_238)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op) {
	NIM_BOOL result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T1_;
	result = (NIM_BOOL)0;
	T1_ = NIM_NIL;
	T1_ = getModule__astalgo_216(op);
	result = (((*T1_).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, min__semparallel_454)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		if (!(a == 0)) goto LA3_;
		result = b;
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*a)._kind_1.intVal < (*b)._kind_1.intVal)) goto LA6_;
		result = a;
	}
	goto LA1_;
	LA6_: ;
	{
		result = b;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkLocal__semparallel_240)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NI s;
		T3_ = (NIM_BOOL)0;
		T3_ = isLocal__semparallel_220(n);
		if (!T3_) goto LA4_;
		s = lookupSlot__semparallel_99(c, (*n)._kind_4.sym);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (((NI) 0) <= s);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*c).locals->data[s].stride == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			LA9_: ;
			if (!T8_) goto LA10_;
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_8), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__JbTimwuMPgU1h9bmgifZk6Q_9, NIM_FALSE);
		}
		LA10_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA15;
					i = i_2;
					checkLocal__semparallel_240(c, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA15: ;
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addLowerBoundAsFacts__semparallel_264)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c) {
	{
		tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA* v;
		NI i;
		NI L;
		NI T2_;
		v = (tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA*)0;
		i = ((NI) 0);
		T2_ = ((*c).locals ? (*c).locals->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				v = (&(*c).locals->data[i]);
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T9_;
					if (!!((*v).blacklisted)) goto LA7_;
					T9_ = NIM_NIL;
					T9_ = newSymNode__ast_3704((*v).v);
					addFactLe__guards_1643((&(*c).guards), (*v).lower, T9_);
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkLe__semparallel_256)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg T1_;
	T1_ = (tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg)0;
	T1_ = proveLe__guards_1628((*c).guards, a, b);
	switch (T1_) {
	case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 0):
	{
		NimStringDesc* T3_;
		NimStringDesc* T4_;
		NimStringDesc* T5_;
		T3_ = NIM_NIL;
		T4_ = NIM_NIL;
		T4_ = renderTree__renderer_46(a, 0);
		T5_ = NIM_NIL;
		T5_ = renderTree__renderer_46(b, 0);
		T3_ = rawNewString((T4_ ? T4_->Sup.len : 0) + (T5_ ? T5_->Sup.len : 0) + 18);
appendString(T3_, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_11));
appendString(T3_, T4_);
appendString(T3_, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_12));
appendString(T3_, T5_);
		liMessage__msgs_1128((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 47), T3_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__JbTimwuMPgU1h9bmgifZk6Q_13, NIM_FALSE);
	}
	break;
	case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 2):
	{
	}
	break;
	case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 1):
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		NimStringDesc* T10_;
		T8_ = NIM_NIL;
		T9_ = NIM_NIL;
		T9_ = renderTree__renderer_46(a, 0);
		T10_ = NIM_NIL;
		T10_ = renderTree__renderer_46(b, 0);
		T8_ = rawNewString((T9_ ? T9_->Sup.len : 0) + (T10_ ? T10_->Sup.len : 0) + 14);
appendString(T8_, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_14));
appendString(T8_, T9_);
appendString(T8_, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_15));
appendString(T8_, T10_);
		liMessage__msgs_1128((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 47), T8_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__JbTimwuMPgU1h9bmgifZk6Q_16, NIM_FALSE);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkBounds__semparallel_260)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arr, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* idx) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T2_;
	T1_ = NIM_NIL;
	T1_ = lowBound__guards_261((*(*c).graph).config, arr);
	checkLe__semparallel_256(c, T1_, idx);
	T2_ = NIM_NIL;
	T2_ = highBound__guards_265((*(*c).graph).config, arr, (&(*(*c).graph).operators));
	checkLe__semparallel_256(c, idx, T2_);
}
static N_NIMCALL(void, Marker_tySequence__IZ4pqIhlSxW1ShEsUUFl9bg)(void* p, NI op) {
	tySequence__IZ4pqIhlSxW1ShEsUUFl9bg* a;
	NI T1_;
	a = (tySequence__IZ4pqIhlSxW1ShEsUUFl9bg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, addSlice__semparallel_294)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le_2;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri_2;
	NI oldState;
	NI T1_;
	tyTuple__4xveOqHv9bUHQvrUN5zZghg T2_;
	NI T3_;
	checkLocal__semparallel_240((&(*c)), n);
	le_2 = canon__guards_345(le, (&(*(*c).graph).operators));
	ri_2 = canon__guards_345(ri, (&(*(*c).graph).operators));
	T1_ = ((*c).guards.s ? (*c).guards.s->Sup.len : 0);
	oldState = T1_;
	addLowerBoundAsFacts__semparallel_264(c);
	checkBounds__semparallel_260((&(*c)), x, le_2);
	checkBounds__semparallel_260((&(*c)), x, ri_2);
	unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*c).guards.s)?&((*c).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldState))));
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__4xveOqHv9bUHQvrUN5zZghg));
	T2_.Field0 = x;
	T2_.Field1 = le_2;
	T2_.Field2 = ri_2;
	T2_.Field3 = (*c).currentSpawnId;
	T2_.Field4 = (((NI) 0) < (*c).inLoop);
	unsureAsgnRef((void**) (&(*c).slices), (tySequence__IZ4pqIhlSxW1ShEsUUFl9bg*) incrSeqV3((TGenericSeq*)((*c).slices), (&NTIseqLtupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolTT__IZ4pqIhlSxW1ShEsUUFl9bg_)));
	T3_ = (*c).slices->Sup.len++;
	genericAssign((void*)(&(*c).slices->data[T3_]), (void*)(&T2_), (&NTItupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolT__4xveOqHv9bUHQvrUN5zZghg_));
}
N_LIB_PRIVATE N_NIMCALL(void, analyseCall__semparallel_464)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op) {
	{
		NI oldSpawnId;
		if (!((*op).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 199))) goto LA3_;
		(*c).spawns += ((NI) 1);
		oldSpawnId = (*c).currentSpawnId;
		(*c).currentSpawnId = (*c).spawns;
		gatherArgs__semparallel_172(c, (*n)._kind_6.sons->data[((NI) 1)]);
		analyseSons__semparallel_445(c, n);
		(*c).currentSpawnId = oldSpawnId;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NIM_BOOL T8_;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*op).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 29));
		if (T6_) goto LA7_;
		T8_ = (NIM_BOOL)0;
		T8_ = eqStrings((*(*op).name).s, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_6));
		if (!(T8_)) goto LA9_;
		T8_ = fromSystem__astalgo_238(op);
		LA9_: ;
		T6_ = T8_;
		LA7_: ;
		if (!T6_) goto LA10_;
		{
			NIM_BOOL T14_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* incr;
			T14_ = (NIM_BOOL)0;
			T14_ = isLocal__semparallel_220((*n)._kind_6.sons->data[((NI) 1)]);
			if (!T14_) goto LA15_;
			incr = skipConv__types_3655((*n)._kind_6.sons->data[((NI) 2)]);
			{
				NIM_BOOL T19_;
				tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA* slot;
				T19_ = (NIM_BOOL)0;
				T19_ = ((*incr).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*incr).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 14));
				if (!(T19_)) goto LA20_;
				T19_ = (IL64(0) < (*incr)._kind_1.intVal);
				LA20_: ;
				if (!T19_) goto LA21_;
				slot = getSlot__semparallel_120(c, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym);
				unsureAsgnRef((void**) (&(*slot).stride), min__semparallel_454((*slot).stride, incr));
			}
			LA21_: ;
		}
		LA15_: ;
		analyseSons__semparallel_445(c, n);
	}
	goto LA1_;
	LA10_: ;
	{
		NIM_BOOL T24_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* slice;
		T24_ = (NIM_BOOL)0;
		T24_ = eqStrings((*(*op).name).s, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_7));
		if (!(T24_)) goto LA25_;
		T24_ = fromSystem__astalgo_238(op);
		LA25_: ;
		if (!T24_) goto LA26_;
		slice = skipStmtList__ast_4813((*n)._kind_6.sons->data[((NI) 2)]);
		addSlice__semparallel_294(c, n, (*n)._kind_6.sons->data[((NI) 1)], (*slice)._kind_6.sons->data[((NI) 1)], (*slice)._kind_6.sons->data[((NI) 2)]);
		analyseSons__semparallel_445(c, n);
	}
	goto LA1_;
	LA26_: ;
	{
		NIM_BOOL T29_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* slice_2;
		T29_ = (NIM_BOOL)0;
		T29_ = eqStrings((*(*op).name).s, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_18));
		if (!(T29_)) goto LA30_;
		T29_ = fromSystem__astalgo_238(op);
		LA30_: ;
		if (!T29_) goto LA31_;
		slice_2 = skipStmtList__ast_4813((*n)._kind_6.sons->data[((NI) 2)]);
		addSlice__semparallel_294(c, n, (*n)._kind_6.sons->data[((NI) 1)], (*slice_2)._kind_6.sons->data[((NI) 1)], (*slice_2)._kind_6.sons->data[((NI) 2)]);
		analyseSons__semparallel_445(c, n);
	}
	goto LA1_;
	LA31_: ;
	{
		analyseSons__semparallel_445(c, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, analyseCase__semparallel_501)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI oldFacts;
	NI T1_;
	analyse__semparallel_442(c, (*n)._kind_6.sons->data[((NI) 0)]);
	T1_ = ((*c).guards.s ? (*c).guards.s->Sup.len : 0);
	oldFacts = T1_;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				branch = (*n)._kind_6.sons->data[i];
				unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*c).guards.s)?&((*c).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts))));
				addCaseBranchFacts__guards_1764((&(*c).guards), n, i);
				{
					NI i_3;
					NI colontmp__2;
					NI i_4;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = len__ast_3155(branch);
					i_4 = ((NI) 0);
					{
						while (1) {
							if (!(i_4 < colontmp__2)) goto LA7;
							i_3 = i_4;
							analyse__semparallel_442(c, (*branch)._kind_6.sons->data[i_3]);
							i_4 += ((NI) 1);
						} LA7: ;
					}
				}
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*c).guards.s)?&((*c).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts))));
}
N_LIB_PRIVATE N_NIMCALL(void, analyseIf__semparallel_536)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI oldFacts;
	NI T1_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T2_;
	analyse__semparallel_442(c, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
	T1_ = ((*c).guards.s ? (*c).guards.s->Sup.len : 0);
	oldFacts = T1_;
	T2_ = NIM_NIL;
	T2_ = canon__guards_345((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)], (&(*(*c).graph).operators));
	addFact__guards_609((&(*c).guards), T2_);
	analyse__semparallel_442(c, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
				if (!(i_2 < colontmp_)) goto LA5;
				i = i_2;
				branch = (*n)._kind_6.sons->data[i];
				unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*c).guards.s)?&((*c).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts))));
				{
					NI j;
					NI colontmp__2;
					NI res;
					j = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = (NI)(i - ((NI) 1));
					res = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T9_;
							if (!(res <= colontmp__2)) goto LA8;
							j = res;
							T9_ = NIM_NIL;
							T9_ = canon__guards_345((*(*n)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)], (&(*(*c).graph).operators));
							addFactNeg__guards_632((&(*c).guards), T9_);
							res += ((NI) 1);
						} LA8: ;
					}
				}
				{
					NI T12_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T15_;
					T12_ = (NI)0;
					T12_ = len__ast_3155(branch);
					if (!(((NI) 1) < T12_)) goto LA13_;
					T15_ = NIM_NIL;
					T15_ = canon__guards_345((*branch)._kind_6.sons->data[((NI) 0)], (&(*(*c).graph).operators));
					addFact__guards_609((&(*c).guards), T15_);
				}
				LA13_: ;
				{
					NI i_3;
					NI colontmp__3;
					NI i_4;
					i_3 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__3 = len__ast_3155(branch);
					i_4 = ((NI) 0);
					{
						while (1) {
							if (!(i_4 < colontmp__3)) goto LA18;
							i_3 = i_4;
							analyse__semparallel_442(c, (*branch)._kind_6.sons->data[i_3]);
							i_4 += ((NI) 1);
						} LA18: ;
					}
				}
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*c).guards.s)?&((*c).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts))));
}
N_LIB_PRIVATE N_NIMCALL(void, analyse__semparallel_442)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value;
		y = skipConv__types_3655((*n)._kind_6.sons->data[((NI) 1)]);
		{
			NIM_BOOL T4_;
			tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA* slot;
			T4_ = (NIM_BOOL)0;
			T4_ = isSingleAssignable__semparallel_200((*n)._kind_6.sons->data[((NI) 0)]);
			if (!(T4_)) goto LA5_;
			T4_ = isLocal__semparallel_220(y);
			LA5_: ;
			if (!T4_) goto LA6_;
			slot = getSlot__semparallel_120(c, (*y)._kind_4.sym);
			unsureAsgnRef((void**) (&(*slot).alias), (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
		}
		goto LA2_;
		LA6_: ;
		{
			NIM_BOOL T9_;
			tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA* slot_2;
			T9_ = (NIM_BOOL)0;
			T9_ = isLocal__semparallel_220((*n)._kind_6.sons->data[((NI) 0)]);
			if (!T9_) goto LA10_;
			slot_2 = getSlot__semparallel_120(c, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			(*slot_2).blacklisted = NIM_TRUE;
		}
		goto LA2_;
		LA10_: ;
		LA2_: ;
		invalidateFacts__guards_760((&(*c).guards), (*n)._kind_6.sons->data[((NI) 0)]);
		value = (*n)._kind_6.sons->data[((NI) 1)];
		{
			tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T14_;
			NI oldSpawnId;
			T14_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
			T14_ = getMagic__trees_137(value);
			if (!(T14_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 199))) goto LA15_;
			(*c).spawns += ((NI) 1);
			oldSpawnId = (*c).currentSpawnId;
			(*c).currentSpawnId = (*c).spawns;
			gatherArgs__semparallel_172(c, (*value)._kind_6.sons->data[((NI) 1)]);
			analyseSons__semparallel_445(c, (*value)._kind_6.sons->data[((NI) 1)]);
			analyse__semparallel_442(c, (*n)._kind_6.sons->data[((NI) 0)]);
			(*c).currentSpawnId = oldSpawnId;
		}
		goto LA12_;
		LA15_: ;
		{
			analyseSons__semparallel_445(c, n);
		}
		LA12_: ;
		addAsgnFact__guards_1739((&(*c).guards), (*n)._kind_6.sons->data[((NI) 0)], y);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA21_;
			analyseCall__semparallel_464(c, n, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
		}
		goto LA19_;
		LA21_: ;
		{
			analyseSons__semparallel_445(c, n);
		}
		LA19_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
	{
		{
			NIM_BOOL T27_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T29_;
			T27_ = (NIM_BOOL)0;
			T27_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T27_)) goto LA28_;
			T29_ = NIM_NIL;
			T29_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__JbTimwuMPgU1h9bmgifZk6Q_19);
			T27_ = !(((*T29_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18)));
			LA28_: ;
			if (!T27_) goto LA30_;
			addSlice__semparallel_294(c, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], (*n)._kind_6.sons->data[((NI) 1)]);
		}
		LA30_: ;
		analyseSons__semparallel_445(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 109):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 108):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 106):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 154):
	{
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_20), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__JbTimwuMPgU1h9bmgifZk6Q_21, NIM_FALSE);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
			it = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value_2;
						NIM_BOOL isSpawned;
						tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T38_;
						if (!(i_2 < colontmp_)) goto LA37;
						i = i_2;
						it = (*n)._kind_6.sons->data[i];
						value_2 = lastSon__ast_4833(it);
						T38_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
						T38_ = getMagic__trees_137(value_2);
						isSpawned = (T38_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 199));
						{
							NI oldSpawnId_2;
							if (!isSpawned) goto LA41_;
							(*c).spawns += ((NI) 1);
							oldSpawnId_2 = (*c).currentSpawnId;
							(*c).currentSpawnId = (*c).spawns;
							gatherArgs__semparallel_172(c, (*value_2)._kind_6.sons->data[((NI) 1)]);
							analyseSons__semparallel_445(c, (*value_2)._kind_6.sons->data[((NI) 1)]);
							(*c).currentSpawnId = oldSpawnId_2;
						}
						LA41_: ;
						{
							if (!!(((*value_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA45_;
							{
								NI j;
								NI colontmp__2;
								NI T48_;
								NI i_3;
								j = (NI)0;
								colontmp__2 = (NI)0;
								T48_ = (NI)0;
								T48_ = len__ast_3155(it);
								colontmp__2 = (NI)(T48_ - ((NI) 2));
								i_3 = ((NI) 0);
								{
									while (1) {
										if (!(i_3 < colontmp__2)) goto LA50;
										j = i_3;
										{
											NIM_BOOL T53_;
											tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA* slot_3;
											T53_ = (NIM_BOOL)0;
											T53_ = isLocal__semparallel_220((*it)._kind_6.sons->data[j]);
											if (!T53_) goto LA54_;
											slot_3 = getSlot__semparallel_120(c, (*(*it)._kind_6.sons->data[j])._kind_4.sym);
											{
												if (!((*slot_3).lower == 0)) goto LA58_;
												unsureAsgnRef((void**) (&(*slot_3).lower), value_2);
											}
											goto LA56_;
											LA58_: ;
											{
												internalErrorImpl__msgs_1441((*(*c).graph).config, (*it).info, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_22), TM__JbTimwuMPgU1h9bmgifZk6Q_23);
											}
											LA56_: ;
										}
										LA54_: ;
										i_3 += ((NI) 1);
									} LA50: ;
								}
							}
							{
								if (!!(isSpawned)) goto LA63_;
								analyse__semparallel_442(c, value_2);
							}
							LA63_: ;
						}
						LA45_: ;
						i_2 += ((NI) 1);
					} LA37: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 97):
	{
		analyseCase__semparallel_501(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	{
		analyseIf__semparallel_536(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96):
	{
		analyse__semparallel_442(c, (*n)._kind_6.sons->data[((NI) 0)]);
		(*c).inLoop += ((NI) 1);
		{
			NIM_BOOL T70_;
			T70_ = (NIM_BOOL)0;
			T70_ = isTrue__trees_375((*n)._kind_6.sons->data[((NI) 0)]);
			if (!T70_) goto LA71_;
			analyseSons__semparallel_445(c, (*n)._kind_6.sons->data[((NI) 1)]);
		}
		goto LA68_;
		LA71_: ;
		{
			NI oldState;
			NI T74_;
			NI oldFacts;
			NI T75_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T76_;
			T74_ = ((*c).locals ? (*c).locals->Sup.len : 0);
			oldState = T74_;
			T75_ = ((*c).guards.s ? (*c).guards.s->Sup.len : 0);
			oldFacts = T75_;
			T76_ = NIM_NIL;
			T76_ = canon__guards_345((*n)._kind_6.sons->data[((NI) 0)], (&(*(*c).graph).operators));
			addFact__guards_609((&(*c).guards), T76_);
			analyse__semparallel_442(c, (*n)._kind_6.sons->data[((NI) 1)]);
			unsureAsgnRef((void**) (&(*c).locals), (tySequence__9akYQg9bGGWN2vXNeTTLyhlQ*) setLengthSeqV2(((*c).locals)?&((*c).locals)->Sup:NIM_NIL, (&NTIseqLmonotonicvarT__9akYQg9bGGWN2vXNeTTLyhlQ_), ((NI) (oldState))));
			unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*c).guards.s)?&((*c).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts))));
			{
				NIM_BOOL T79_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T82_;
				T79_ = (NIM_BOOL)0;
				T79_ = hasSubnodeWith__ast_4571((*n)._kind_6.sons->data[((NI) 1)], ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 110));
				if (!!(T79_)) goto LA80_;
				T82_ = NIM_NIL;
				T82_ = canon__guards_345((*n)._kind_6.sons->data[((NI) 0)], (&(*(*c).graph).operators));
				addFactNeg__guards_632((&(*c).guards), T82_);
			}
			LA80_: ;
		}
		LA68_: ;
		(*c).inLoop -= ((NI) 1);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 122):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 118):
	{
	}
	break;
	default:
	{
		analyseSons__semparallel_445(c, n);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, overlap__semparallel_323)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* d) {
	tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg T1_;
	T1_ = (tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg)0;
	T1_ = proveLe__guards_1628(m, c, y);
	switch (T1_) {
	case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 0):
	{
		tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg T3_;
		T3_ = (tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg)0;
		T3_ = proveLe__guards_1628(m, x, d);
		switch (T3_) {
		case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 1):
		{
		}
		break;
		case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 0):
		case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 2):
		{
			tyArray__yt5VDPNtUGx9cBkOVakHwdQ T6_;
			NimStringDesc* T7_;
			nimZeroMem((void*)T6_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
			T6_[0] = renderTree__renderer_46(c, 0);
			T6_[1] = renderTree__renderer_46(y, 0);
			T6_[2] = renderTree__renderer_46(x, 0);
			T6_[3] = renderTree__renderer_46(y, 0);
			T6_[4] = renderTree__renderer_46(c, 0);
			T6_[5] = renderTree__renderer_46(d, 0);
			T7_ = NIM_NIL;
			T7_ = nsuFormatOpenArray(((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_26), T6_, 6);
			liMessage__msgs_1128(conf, (*x).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 47), T7_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__JbTimwuMPgU1h9bmgifZk6Q_27, NIM_FALSE);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 2):
	{
		tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg T9_;
		T9_ = (tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg)0;
		T9_ = proveLe__guards_1628(m, x, d);
		switch (T9_) {
		case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 0):
		{
			tyArray__yt5VDPNtUGx9cBkOVakHwdQ T11_;
			NimStringDesc* T12_;
			nimZeroMem((void*)T11_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
			T11_[0] = renderTree__renderer_46(x, 0);
			T11_[1] = renderTree__renderer_46(d, 0);
			T11_[2] = renderTree__renderer_46(x, 0);
			T11_[3] = renderTree__renderer_46(y, 0);
			T11_[4] = renderTree__renderer_46(c, 0);
			T11_[5] = renderTree__renderer_46(d, 0);
			T12_ = NIM_NIL;
			T12_ = nsuFormatOpenArray(((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_26), T11_, 6);
			liMessage__msgs_1128(conf, (*x).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 47), T12_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__JbTimwuMPgU1h9bmgifZk6Q_28, NIM_FALSE);
		}
		break;
		case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 2):
		{
			tyArray__yt5VDPNtUGx9cBkOVakHwdQ T14_;
			NimStringDesc* T15_;
			nimZeroMem((void*)T14_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
			T14_[0] = renderTree__renderer_46(c, 0);
			T14_[1] = renderTree__renderer_46(y, 0);
			T14_[2] = renderTree__renderer_46(x, 0);
			T14_[3] = renderTree__renderer_46(y, 0);
			T14_[4] = renderTree__renderer_46(c, 0);
			T14_[5] = renderTree__renderer_46(d, 0);
			T15_ = NIM_NIL;
			T15_ = nsuFormatOpenArray(((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_29), T14_, 6);
			liMessage__msgs_1128(conf, (*x).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 47), T15_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__JbTimwuMPgU1h9bmgifZk6Q_30, NIM_FALSE);
		}
		break;
		case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 1):
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 1):
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, subStride__semparallel_349)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NI s;
		T3_ = (NIM_BOOL)0;
		T3_ = isLocal__semparallel_220(n);
		if (!T3_) goto LA4_;
		s = lookupSlot__semparallel_99(c, (*n)._kind_4.sym);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (((NI) 0) <= s);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*c).locals->data[s].stride == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			LA9_: ;
			if (!T8_) goto LA10_;
			result = buildAdd__guards_494(n, (*(*c).locals->data[s].stride)._kind_1.intVal, (&(*(*c).graph).operators));
		}
		goto LA6_;
		LA10_: ;
		{
			result = n;
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		NI T14_;
		T14_ = (NI)0;
		T14_ = safeLen__ast_3148(n);
		if (!(((NI) 0) < T14_)) goto LA15_;
		result = shallowCopy__ast_4414(n);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA19;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), subStride__semparallel_349(c, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA19: ;
			}
		}
	}
	goto LA1_;
	LA15_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI64, stride__semparallel_330)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI64 result;
	result = (NI64)0;
	{
		NIM_BOOL T3_;
		NI s;
		T3_ = (NIM_BOOL)0;
		T3_ = isLocal__semparallel_220(n);
		if (!T3_) goto LA4_;
		s = lookupSlot__semparallel_99(c, (*n)._kind_4.sym);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (((NI) 0) <= s);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*c).locals->data[s].stride == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			LA9_: ;
			if (!T8_) goto LA10_;
			result = (*(*c).locals->data[s].stride)._kind_1.intVal;
		}
		LA10_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					NI64 T16_;
					if (!(i_2 < colontmp_)) goto LA15;
					i = i_2;
					T16_ = (NI64)0;
					T16_ = stride__semparallel_330(c, (*n)._kind_6.sons->data[i]);
					result += T16_;
					i_2 += ((NI) 1);
				} LA15: ;
			}
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkSlicesAreDisjoint__semparallel_368)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* c) {
	addLowerBoundAsFacts__semparallel_264(c);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** x;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** a;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** b;
		NI* id;
		NIM_BOOL* inLoop;
		NI i;
		NI L;
		NI T2_;
		x = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
		a = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
		b = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
		id = (NI*)0;
		inLoop = (NIM_BOOL*)0;
		i = ((NI) 0);
		T2_ = ((*c).slices ? (*c).slices->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				x = &(*c).slices->data[i].Field0;
				a = &(*c).slices->data[i].Field1;
				b = &(*c).slices->data[i].Field2;
				id = (&(*c).slices->data[i].Field3);
				inLoop = (&(*c).slices->data[i].Field4);
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T9_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T10_;
					if (!(*inLoop)) goto LA7_;
					T9_ = NIM_NIL;
					T9_ = subStride__semparallel_349((&(*c)), (*a));
					T10_ = NIM_NIL;
					T10_ = subStride__semparallel_349((&(*c)), (*b));
					overlap__semparallel_323((*c).guards, (*(*c).graph).config, (*a), (*b), T9_, T10_);
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NI i_2;
		NI colontmp_;
		NI T12_;
		NI res;
		i_2 = (NI)0;
		colontmp_ = (NI)0;
		T12_ = (((*c).slices ? (*c).slices->Sup.len : 0)-1);
		colontmp_ = T12_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA14;
				i_2 = res;
				{
					NI j;
					NI colontmp__2;
					NI colontmp__3;
					NI T16_;
					NI res_2;
					j = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__2 = (NI)(i_2 + ((NI) 1));
					T16_ = (((*c).slices ? (*c).slices->Sup.len : 0)-1);
					colontmp__3 = T16_;
					res_2 = colontmp__2;
					{
						while (1) {
							tyTuple__4xveOqHv9bUHQvrUN5zZghg x_2;
							tyTuple__4xveOqHv9bUHQvrUN5zZghg y;
							if (!(res_2 <= colontmp__3)) goto LA18;
							j = res_2;
							nimZeroMem((void*)(&x_2), sizeof(tyTuple__4xveOqHv9bUHQvrUN5zZghg));
							nimCopyMem((void*)(&x_2), (NIM_CONST void*)(&(*c).slices->data[i_2]), sizeof(x_2));
							nimZeroMem((void*)(&y), sizeof(tyTuple__4xveOqHv9bUHQvrUN5zZghg));
							nimCopyMem((void*)(&y), (NIM_CONST void*)(&(*c).slices->data[j]), sizeof(y));
							{
								NIM_BOOL T21_;
								T21_ = (NIM_BOOL)0;
								T21_ = !((x_2.Field3 == y.Field3));
								if (!(T21_)) goto LA22_;
								T21_ = sameTree__guards_680(x_2.Field0, y.Field0);
								LA22_: ;
								if (!T21_) goto LA23_;
								{
									NIM_BOOL T27_;
									T27_ = (NIM_BOOL)0;
									T27_ = !(x_2.Field4);
									if (T27_) goto LA28_;
									T27_ = !(y.Field4);
									LA28_: ;
									if (!T27_) goto LA29_;
									overlap__semparallel_323((*c).guards, (*(*c).graph).config, x_2.Field1, x_2.Field2, y.Field1, y.Field2);
								}
								goto LA25_;
								LA29_: ;
								{
									NI64 k;
									NI64 m;
									NIM_BOOL T32_;
									NI64 stride;
									NI64 T36_;
									NI64 T37_;
									k = simpleSlice__guards_1048(x_2.Field1, x_2.Field2);
									m = simpleSlice__guards_1048(y.Field1, y.Field2);
									T32_ = (NIM_BOOL)0;
									T32_ = (IL64(0) <= k);
									if (!(T32_)) goto LA33_;
									T32_ = (IL64(0) <= m);
									LA33_: ;
									if (!T32_) goto LA34_;
									overlap__semparallel_323((*c).guards, (*(*c).graph).config, x_2.Field1, x_2.Field2, y.Field1, y.Field2);
									T36_ = (NI64)0;
									T36_ = stride__semparallel_330((&(*c)), x_2.Field1);
									T37_ = (NI64)0;
									T37_ = stride__semparallel_330((&(*c)), y.Field1);
									stride = ((T36_ <= T37_) ? T36_ : T37_);
									{
										NIM_BOOL T40_;
										T40_ = (NIM_BOOL)0;
										T40_ = (k < stride);
										if (!(T40_)) goto LA41_;
										T40_ = (m < stride);
										LA41_: ;
										if (!T40_) goto LA42_;
									}
									goto LA38_;
									LA42_: ;
									{
										tyArray__sMpvt1sOxOJ3LFGulnbeMQ T45_;
										NimStringDesc* T46_;
										nimZeroMem((void*)T45_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
										T45_[0] = renderTree__renderer_46(x_2.Field1, 0);
										T45_[1] = renderTree__renderer_46(x_2.Field2, 0);
										T45_[2] = renderTree__renderer_46(y.Field1, 0);
										T45_[3] = renderTree__renderer_46(y.Field2, 0);
										T46_ = NIM_NIL;
										T46_ = nsuFormatOpenArray(((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_31), T45_, 4);
										liMessage__msgs_1128((*(*c).graph).config, (*x_2.Field0).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T46_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__JbTimwuMPgU1h9bmgifZk6Q_32, NIM_FALSE);
									}
									LA38_: ;
								}
								goto LA25_;
								LA34_: ;
								{
									tyArray__sMpvt1sOxOJ3LFGulnbeMQ T48_;
									NimStringDesc* T49_;
									nimZeroMem((void*)T48_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
									T48_[0] = renderTree__renderer_46(x_2.Field1, 0);
									T48_[1] = renderTree__renderer_46(x_2.Field2, 0);
									T48_[2] = renderTree__renderer_46(y.Field1, 0);
									T48_[3] = renderTree__renderer_46(y.Field2, 0);
									T49_ = NIM_NIL;
									T49_ = nsuFormatOpenArray(((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_31), T48_, 4);
									liMessage__msgs_1128((*(*c).graph).config, (*x_2.Field0).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T49_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__JbTimwuMPgU1h9bmgifZk6Q_33, NIM_FALSE);
								}
								LA25_: ;
							}
							LA23_: ;
							res_2 += ((NI) 1);
						} LA18: ;
					}
				}
				res += ((NI) 1);
			} LA14: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkArgs__semparallel_849)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, generateAliasChecks__semparallel_852)(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result) {
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).typeId_0 += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).typeId_0;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, transformSlices__semparallel_699)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		LA4_: ;
		if (!T3_) goto LA5_;
		op = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			NIM_BOOL T9_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
			tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T13_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* opSlice;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T14_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* slice;
			T9_ = (NIM_BOOL)0;
			T9_ = eqStrings((*(*op).name).s, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_7));
			if (!(T9_)) goto LA10_;
			T9_ = fromSystem__astalgo_238(op);
			LA10_: ;
			if (!T9_) goto LA11_;
			result = copyNode__ast_4324(n);
			T13_ = nextTypeId__ast_3122((*g).idgen);
			typ = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27), T13_, (*(*result).typ).owner);
			add__concepts_23(typ, (*(*result).typ).sons->data[((NI) 0)]);
			asgnRef((void**) (&(*result).typ), typ);
			T14_ = NIM_NIL;
			T14_ = createMagic__modulegraphs_9046(g, idgen, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_39), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 126));
			opSlice = newSymNode__ast_3704(T14_);
			asgnRef((void**) (&(*opSlice).typ), getSysType__magicsys_60(g, (*n).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31)));
			add__ast_4798(result, opSlice);
			add__ast_4798(result, (*n)._kind_6.sons->data[((NI) 1)]);
			slice = skipStmtList__ast_4813((*n)._kind_6.sons->data[((NI) 2)]);
			add__ast_4798(result, (*slice)._kind_6.sons->data[((NI) 1)]);
			add__ast_4798(result, (*slice)._kind_6.sons->data[((NI) 2)]);
			goto BeforeRet_;
		}
		LA11_: ;
	}
	LA5_: ;
	{
		NI T17_;
		T17_ = (NI)0;
		T17_ = safeLen__ast_3148(n);
		if (!(((NI) 0) < T17_)) goto LA18_;
		result = shallowCopy__ast_4414(n);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA22;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), transformSlices__semparallel_699(g, idgen, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA22: ;
			}
		}
	}
	goto LA15_;
	LA18_: ;
	{
		result = n;
	}
	LA15_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, transformSpawnSons__semparallel_759)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* barrier) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = shallowCopy__ast_4414(n);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				asgnRef((void**) (&(*result)._kind_6.sons->data[i]), transformSpawn__semparallel_753(g, idgen, owner, (*n)._kind_6.sons->data[i], barrier));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, transformSpawn__semparallel_753)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* barrier) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	{
		result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
			it = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b;
						if (!(i_2 < colontmp_)) goto LA5;
						i = i_2;
						it = (*n)._kind_6.sons->data[i];
						b = lastSon__ast_4833(it);
						{
							tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T8_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* m;
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
							T8_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
							T8_ = getMagic__trees_137(b);
							if (!(T8_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 199))) goto LA9_;
							{
								NI T13_;
								T13_ = (NI)0;
								T13_ = len__ast_3155(it);
								if (!!((T13_ == ((NI) 3)))) goto LA14_;
								liMessage__msgs_1128((*g).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_37), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__JbTimwuMPgU1h9bmgifZk6Q_38, NIM_FALSE);
							}
							LA14_: ;
							m = transformSlices__semparallel_699(g, idgen, b);
							{
								if (!(result == 0)) goto LA18_;
								result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*n).info);
								add__ast_4798(result, n);
							}
							LA18_: ;
							t = (*(*(*(*b)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)]).typ).sons->data[((NI) 0)];
							{
								tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA T22_;
								tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T25_;
								NI T26_;
								T22_ = (tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA)0;
								T22_ = spawnResult__spawn_34(t, NIM_TRUE);
								if (!(T22_ == ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 2))) goto LA23_;
								T25_ = NIM_NIL;
								T25_ = wrapProcForSpawn__spawn_510(g, idgen, owner, m, (*b).typ, barrier, (*it)._kind_6.sons->data[((NI) 0)]);
								add__ast_4798(result, T25_);
								T26_ = (NI)0;
								T26_ = len__ast_3155(it);
								asgnRef((void**) (&(*it)._kind_6.sons->data[(NI)(T26_ - ((NI) 1))]), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1), (*it).info));
							}
							goto LA20_;
							LA23_: ;
							{
								NI T28_;
								T28_ = (NI)0;
								T28_ = len__ast_3155(it);
								asgnRef((void**) (&(*it)._kind_6.sons->data[(NI)(T28_ - ((NI) 1))]), wrapProcForSpawn__spawn_510(g, idgen, owner, m, (*b).typ, barrier, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
							}
							LA20_: ;
						}
						LA9_: ;
						i_2 += ((NI) 1);
					} LA5: ;
				}
			}
		}
		{
			if (!(result == 0)) goto LA31_;
			result = n;
		}
		LA31_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b_2;
		b_2 = (*n)._kind_6.sons->data[((NI) 1)];
		{
			NIM_BOOL T36_;
			tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T37_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
			tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA T39_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* m_2;
			T36_ = (NIM_BOOL)0;
			T37_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
			T37_ = getMagic__trees_137(b_2);
			T36_ = (T37_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 199));
			if (!(T36_)) goto LA38_;
			t_2 = (*(*(*(*b_2)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)]).typ).sons->data[((NI) 0)];
			T39_ = (tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA)0;
			T39_ = spawnResult__spawn_34(t_2, NIM_TRUE);
			T36_ = (T39_ == ((tyEnum_TSpawnResult__EdP9a1q3b9blEXGzohsyvYgA) 2));
			LA38_: ;
			if (!T36_) goto LA40_;
			m_2 = transformSlices__semparallel_699(g, idgen, b_2);
			result = wrapProcForSpawn__spawn_510(g, idgen, owner, m_2, (*b_2).typ, barrier, (*n)._kind_6.sons->data[((NI) 0)]);
			goto BeforeRet_;
		}
		LA40_: ;
		result = transformSpawnSons__semparallel_759(g, idgen, owner, n, barrier);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		{
			tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T45_;
			T45_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
			T45_ = getMagic__trees_137(n);
			if (!(T45_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 199))) goto LA46_;
			result = transformSlices__semparallel_699(g, idgen, n);
			result = wrapProcForSpawn__spawn_510(g, idgen, owner, result, (*n).typ, barrier, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
			goto BeforeRet_;
		}
		LA46_: ;
		result = transformSpawnSons__semparallel_759(g, idgen, owner, n, barrier);
	}
	break;
	default:
	{
		{
			NI T51_;
			T51_ = (NI)0;
			T51_ = safeLen__ast_3148(n);
			if (!(((NI) 0) < T51_)) goto LA52_;
			result = transformSpawnSons__semparallel_759(g, idgen, owner, n, barrier);
		}
		goto LA49_;
		LA52_: ;
		{
			result = n;
		}
		LA49_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, liftParallel__semparallel_855)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA a;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* varSection;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* temp;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T5_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T6_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T7_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tempNode;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* barrier;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T8_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T9_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T10_;
	result = NIM_NIL;
	nimZeroMem((void*)(&a), sizeof(tyObject_AnalysisCtx__JLSSCm0Hj5XBoQVOZ3KFMA));
	initAnalysisCtx__semparallel_44(g, (&a));
	body = lastSon__ast_4833(n);
	analyse__semparallel_442((&a), body);
	{
		if (!(a.spawns == ((NI) 0))) goto LA3_;
		liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_24), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__JbTimwuMPgU1h9bmgifZk6Q_25, NIM_FALSE);
	}
	LA3_: ;
	checkSlicesAreDisjoint__semparallel_368((&a));
	checkArgs__semparallel_849((&a), body);
	varSection = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99), (*n).info);
	T5_ = NIM_NIL;
	T5_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_34));
	T6_ = nextSymId__ast_3103(idgen);
	temp = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 5), T5_, T6_, owner, (*n).info, 0);
	T7_ = NIM_NIL;
	T7_ = getCompilerProc__magicsys_145(g, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_35));
	asgnRef((void**) (&(*temp).typ), (*T7_).typ);
	(*temp).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 2)) & 63);
	tempNode = newSymNode__ast_3704(temp);
	addVar__lowerings_63(varSection, tempNode);
	barrier = genAddrOf__lowerings_626(tempNode, idgen, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21));
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*n).info);
	generateAliasChecks__semparallel_852((&a), result);
	add__ast_4798(result, varSection);
	T8_ = NIM_NIL;
	T8_ = callCodegenProc__lowerings_641(g, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_36), (*barrier).info, barrier, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	add__ast_4798(result, T8_);
	T9_ = NIM_NIL;
	T9_ = transformSpawn__semparallel_753(g, idgen, owner, body, barrier);
	add__ast_4798(result, T9_);
	T10_ = NIM_NIL;
	T10_ = callCodegenProc__lowerings_641(g, ((NimStringDesc*) &TM__JbTimwuMPgU1h9bmgifZk6Q_40), (*barrier).info, barrier, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	add__ast_4798(result, T10_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmsemparalleldotnim_DatInit000)(void) {
static TNimNode* TM__JbTimwuMPgU1h9bmgifZk6Q_2_7[7];
static TNimNode* TM__JbTimwuMPgU1h9bmgifZk6Q_3_2[2];
NI TM__JbTimwuMPgU1h9bmgifZk6Q_5;
static char* NIM_CONST TM__JbTimwuMPgU1h9bmgifZk6Q_4[2] = {
"ascending", 
"descending"};
static TNimNode* TM__JbTimwuMPgU1h9bmgifZk6Q_17_5[5];
static TNimNode TM__JbTimwuMPgU1h9bmgifZk6Q_0[17];
NTImonotonicvar__nLLlLWL1ObfBpnV7hTHjSA_.size = sizeof(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA);
NTImonotonicvar__nLLlLWL1ObfBpnV7hTHjSA_.align = NIM_ALIGNOF(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA);
NTImonotonicvar__nLLlLWL1ObfBpnV7hTHjSA_.kind = 18;
NTImonotonicvar__nLLlLWL1ObfBpnV7hTHjSA_.base = 0;
NTImonotonicvar__nLLlLWL1ObfBpnV7hTHjSA_.flags = 2;
TM__JbTimwuMPgU1h9bmgifZk6Q_2_7[0] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[1];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[1].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[1].offset = offsetof(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA, v);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[1].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[1].name = "v";
TM__JbTimwuMPgU1h9bmgifZk6Q_2_7[1] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[2];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[2].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[2].offset = offsetof(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA, alias);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[2].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[2].name = "alias";
TM__JbTimwuMPgU1h9bmgifZk6Q_2_7[2] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[3];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[3].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[3].offset = offsetof(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA, lower);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[3].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[3].name = "lower";
TM__JbTimwuMPgU1h9bmgifZk6Q_2_7[3] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[4];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[4].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[4].offset = offsetof(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA, upper);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[4].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[4].name = "upper";
TM__JbTimwuMPgU1h9bmgifZk6Q_2_7[4] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[5];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[5].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[5].offset = offsetof(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA, stride);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[5].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[5].name = "stride";
TM__JbTimwuMPgU1h9bmgifZk6Q_2_7[5] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[6];
NTItdirection__Q9bgfkfWy7Of6Rrlhl66fXA_.size = sizeof(tyEnum_TDirection__Q9bgfkfWy7Of6Rrlhl66fXA);
NTItdirection__Q9bgfkfWy7Of6Rrlhl66fXA_.align = NIM_ALIGNOF(tyEnum_TDirection__Q9bgfkfWy7Of6Rrlhl66fXA);
NTItdirection__Q9bgfkfWy7Of6Rrlhl66fXA_.kind = 14;
NTItdirection__Q9bgfkfWy7Of6Rrlhl66fXA_.base = 0;
NTItdirection__Q9bgfkfWy7Of6Rrlhl66fXA_.flags = 3;
for (TM__JbTimwuMPgU1h9bmgifZk6Q_5 = 0; TM__JbTimwuMPgU1h9bmgifZk6Q_5 < 2; TM__JbTimwuMPgU1h9bmgifZk6Q_5++) {
TM__JbTimwuMPgU1h9bmgifZk6Q_0[TM__JbTimwuMPgU1h9bmgifZk6Q_5+7].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[TM__JbTimwuMPgU1h9bmgifZk6Q_5+7].offset = TM__JbTimwuMPgU1h9bmgifZk6Q_5;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[TM__JbTimwuMPgU1h9bmgifZk6Q_5+7].name = TM__JbTimwuMPgU1h9bmgifZk6Q_4[TM__JbTimwuMPgU1h9bmgifZk6Q_5];
TM__JbTimwuMPgU1h9bmgifZk6Q_3_2[TM__JbTimwuMPgU1h9bmgifZk6Q_5] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[TM__JbTimwuMPgU1h9bmgifZk6Q_5+7];
}
TM__JbTimwuMPgU1h9bmgifZk6Q_0[9].len = 2; TM__JbTimwuMPgU1h9bmgifZk6Q_0[9].kind = 2; TM__JbTimwuMPgU1h9bmgifZk6Q_0[9].sons = &TM__JbTimwuMPgU1h9bmgifZk6Q_3_2[0];
NTItdirection__Q9bgfkfWy7Of6Rrlhl66fXA_.node = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[9];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[6].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[6].offset = offsetof(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA, dir);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[6].typ = (&NTItdirection__Q9bgfkfWy7Of6Rrlhl66fXA_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[6].name = "dir";
TM__JbTimwuMPgU1h9bmgifZk6Q_2_7[6] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[10];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[10].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[10].offset = offsetof(tyObject_MonotonicVar__nLLlLWL1ObfBpnV7hTHjSA, blacklisted);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[10].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[10].name = "blacklisted";
TM__JbTimwuMPgU1h9bmgifZk6Q_0[0].len = 7; TM__JbTimwuMPgU1h9bmgifZk6Q_0[0].kind = 2; TM__JbTimwuMPgU1h9bmgifZk6Q_0[0].sons = &TM__JbTimwuMPgU1h9bmgifZk6Q_2_7[0];
NTImonotonicvar__nLLlLWL1ObfBpnV7hTHjSA_.node = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[0];
NTIseqLmonotonicvarT__9akYQg9bGGWN2vXNeTTLyhlQ_.size = sizeof(tySequence__9akYQg9bGGWN2vXNeTTLyhlQ*);
NTIseqLmonotonicvarT__9akYQg9bGGWN2vXNeTTLyhlQ_.align = NIM_ALIGNOF(tySequence__9akYQg9bGGWN2vXNeTTLyhlQ*);
NTIseqLmonotonicvarT__9akYQg9bGGWN2vXNeTTLyhlQ_.kind = 24;
NTIseqLmonotonicvarT__9akYQg9bGGWN2vXNeTTLyhlQ_.base = (&NTImonotonicvar__nLLlLWL1ObfBpnV7hTHjSA_);
NTIseqLmonotonicvarT__9akYQg9bGGWN2vXNeTTLyhlQ_.flags = 2;
NTIseqLmonotonicvarT__9akYQg9bGGWN2vXNeTTLyhlQ_.marker = Marker_tySequence__9akYQg9bGGWN2vXNeTTLyhlQ;
NTItupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolT__4xveOqHv9bUHQvrUN5zZghg_.size = sizeof(tyTuple__4xveOqHv9bUHQvrUN5zZghg);
NTItupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolT__4xveOqHv9bUHQvrUN5zZghg_.align = NIM_ALIGNOF(tyTuple__4xveOqHv9bUHQvrUN5zZghg);
NTItupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolT__4xveOqHv9bUHQvrUN5zZghg_.kind = 18;
NTItupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolT__4xveOqHv9bUHQvrUN5zZghg_.base = 0;
NTItupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolT__4xveOqHv9bUHQvrUN5zZghg_.flags = 2;
TM__JbTimwuMPgU1h9bmgifZk6Q_17_5[0] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[12];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[12].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[12].offset = offsetof(tyTuple__4xveOqHv9bUHQvrUN5zZghg, Field0);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[12].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[12].name = "Field0";
TM__JbTimwuMPgU1h9bmgifZk6Q_17_5[1] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[13];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[13].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[13].offset = offsetof(tyTuple__4xveOqHv9bUHQvrUN5zZghg, Field1);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[13].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[13].name = "Field1";
TM__JbTimwuMPgU1h9bmgifZk6Q_17_5[2] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[14];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[14].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[14].offset = offsetof(tyTuple__4xveOqHv9bUHQvrUN5zZghg, Field2);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[14].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[14].name = "Field2";
TM__JbTimwuMPgU1h9bmgifZk6Q_17_5[3] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[15];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[15].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[15].offset = offsetof(tyTuple__4xveOqHv9bUHQvrUN5zZghg, Field3);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[15].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[15].name = "Field3";
TM__JbTimwuMPgU1h9bmgifZk6Q_17_5[4] = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[16];
TM__JbTimwuMPgU1h9bmgifZk6Q_0[16].kind = 1;
TM__JbTimwuMPgU1h9bmgifZk6Q_0[16].offset = offsetof(tyTuple__4xveOqHv9bUHQvrUN5zZghg, Field4);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[16].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__JbTimwuMPgU1h9bmgifZk6Q_0[16].name = "Field4";
TM__JbTimwuMPgU1h9bmgifZk6Q_0[11].len = 5; TM__JbTimwuMPgU1h9bmgifZk6Q_0[11].kind = 2; TM__JbTimwuMPgU1h9bmgifZk6Q_0[11].sons = &TM__JbTimwuMPgU1h9bmgifZk6Q_17_5[0];
NTItupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolT__4xveOqHv9bUHQvrUN5zZghg_.node = &TM__JbTimwuMPgU1h9bmgifZk6Q_0[11];
NTIseqLtupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolTT__IZ4pqIhlSxW1ShEsUUFl9bg_.size = sizeof(tySequence__IZ4pqIhlSxW1ShEsUUFl9bg*);
NTIseqLtupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolTT__IZ4pqIhlSxW1ShEsUUFl9bg_.align = NIM_ALIGNOF(tySequence__IZ4pqIhlSxW1ShEsUUFl9bg*);
NTIseqLtupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolTT__IZ4pqIhlSxW1ShEsUUFl9bg_.kind = 24;
NTIseqLtupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolTT__IZ4pqIhlSxW1ShEsUUFl9bg_.base = (&NTItupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolT__4xveOqHv9bUHQvrUN5zZghg_);
NTIseqLtupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolTT__IZ4pqIhlSxW1ShEsUUFl9bg_.flags = 2;
NTIseqLtupleLx58pnode_a58pnode_b58pnode_spawnid58int_inloop58boolTT__IZ4pqIhlSxW1ShEsUUFl9bg_.marker = Marker_tySequence__IZ4pqIhlSxW1ShEsUUFl9bg;
}

